@@ -25,7 +25,6 @@ import os
 
 import six.moves.urllib.parse as urlparse
 import six.moves.urllib.request as urllib
-import suds.sax.element as element
 
 from oslo_vmware._i18n import _LW
 from oslo_vmware import service
@@ -42,7 +41,7 @@ class Pbm(service.Service):
 
     def __init__(self, protocol='https', host='localhost', port=443,
                  wsdl_url=None, cacert=None, insecure=True, pool_maxsize=10,
-                 connection_timeout=None):
+                 connection_timeout=None, op_id_prefix='oslo.vmware'):
         """Constructs a PBM service client object.
 
         :param protocol: http or https
@@ -55,21 +54,22 @@ class Pbm(service.Service):
                          used only if cacert is not specified
         :param pool_maxsize: Maximum number of connections in http
                              connection pool
+        :param op_id_prefix: String prefix for the operation ID.
         :param connection_timeout: Maximum time in seconds to wait for peer to
                                    respond.
         """
         base_url = service.Service.build_base_url(protocol, host, port)
         soap_url = base_url + '/pbm'
         super(Pbm, self).__init__(wsdl_url, soap_url, cacert, insecure,
-                                  pool_maxsize, connection_timeout)
+                                  pool_maxsize, connection_timeout,
+                                  op_id_prefix)
 
     def set_soap_cookie(self, cookie):
         """Set the specified vCenter session cookie in the SOAP header
 
         :param cookie: cookie to set
         """
-        elem = element.Element('vcSessionCookie').setText(cookie)
-        self.client.set_options(soapheaders=elem)
+        self._vc_session_cookie = cookie
 
     def retrieve_service_content(self):
         ref = vim_util.get_moref(service.SERVICE_INSTANCE, SERVICE_TYPE)
