@@ -22,6 +22,7 @@ import os
 
 import netaddr
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import requests
 import six
 import six.moves.http_client as httplib
@@ -29,6 +30,7 @@ import suds
 from suds import cache
 from suds import client
 from suds import plugin
+import suds.sax.element as element
 from suds import transport
 
 from oslo_vmware._i18n import _
@@ -70,6 +72,7 @@ class ServiceMessagePlugin(plugin.MessagePlugin):
         # Suds builds the entire request object based on the WSDL schema.
         # VI SDK throws server errors if optional SOAP nodes are sent
         # without values; e.g., <test/> as opposed to <test>test</test>.
+
         context.envelope.prune()
         context.envelope.walk(self.add_attribute_for_value)
 
@@ -194,9 +197,10 @@ class Service(object):
 
     def __init__(self, wsdl_url=None, soap_url=None,
                  cacert=None, insecure=True, pool_maxsize=10,
-                 connection_timeout=None):
+                 connection_timeout=None, op_id_prefix='oslo.vmware'):
         self.wsdl_url = wsdl_url
         self.soap_url = soap_url
+        self.op_id_prefix = op_id_prefix
         LOG.debug("Creating suds client with soap_url='%s' and wsdl_url='%s'",
                   self.soap_url, self.wsdl_url)
         transport = RequestsTransport(cacert=cacert,
@@ -209,6 +213,7 @@ class Service(object):
                                     plugins=[ServiceMessagePlugin()],
                                     cache=_CACHE)
         self._service_content = None
+        self._vc_session_cookie = None
 
     @staticmethod
     def build_base_url(protocol, host, port):
@@ -260,6 +265,25 @@ class Service(object):
                                                fault_string,
                                                details=details)
 
+    def _set_soap_headers(self, op_id):
+        """Set SOAP headers for the next remote call to vCenter.
+
+        SOAP headers may include operation ID and vcSessionCookie.
+        The operation ID is a random string which allows to correlate log
+        messages across different systems (OpenStack, vCenter, ESX).
+        vcSessionCookie is needed when making PBM calls.
+        """
+        headers = []
+        if self._vc_session_cookie:
+            elem = element.Element('vcSessionCookie').setText(
+                self._vc_session_cookie)
+            headers.append(elem)
+        if op_id:
+            elem = element.Element('operationID').setText(op_id)
+            headers.append(elem)
+        if headers:
+            self.client.set_options(soapheaders=headers)
+
     @property
     def service_content(self):
         if self._service_content is None:
@@ -297,6 +321,19 @@ class Service(object):
                                                         managed_object)
                 if managed_object is None:
                     return
+
+                skip_op_id = kwargs.pop('skip_op_id', False)
+                op_id = None
+                if not skip_op_id:
+                    # Generate opID. It will appear in vCenter and ESX logs for
+                    # this particular remote call.
+                    op_id = '%s-%s' % (self.op_id_prefix,
+                                       uuidutils.generate_uuid())
+                    LOG.debug('Invoking %s.%s with opID=%s',
+                              managed_object._type,
+                              attr_name,
+                              op_id)
+                self._set_soap_headers(op_id)
                 request = getattr(self.client.service, attr_name)
                 response = request(managed_object, **kwargs)
                 if (attr_name.lower() == 'retrievepropertiesex'):
