@@ -137,7 +137,8 @@ class VMwareAPISessionTest(base.TestCase):
             cacert=self.cert_mock,
             insecure=False,
             pool_maxsize=VMwareAPISessionTest.POOL_SIZE,
-            connection_timeout=None)
+            connection_timeout=None,
+            op_id_prefix='oslo.vmware')
 
     @mock.patch.object(pbm, 'Pbm')
     def test_pbm(self, pbm_mock):
@@ -412,7 +413,8 @@ class VMwareAPISessionTest(base.TestCase):
         api_session.invoke_api.assert_called_with(vim_util,
                                                   'get_object_property',
                                                   api_session.vim, task,
-                                                  'info')
+                                                  'info',
+                                                  skip_op_id=True)
         self.assertEqual(task_info_list_size,
                          api_session.invoke_api.call_count)
 
@@ -437,7 +439,8 @@ class VMwareAPISessionTest(base.TestCase):
         api_session.invoke_api.assert_called_with(vim_util,
                                                   'get_object_property',
                                                   api_session.vim, task,
-                                                  'info')
+                                                  'info',
+                                                  skip_op_id=True)
         self.assertEqual(task_info_list_size,
                          api_session.invoke_api.call_count)
 
@@ -453,7 +456,8 @@ class VMwareAPISessionTest(base.TestCase):
         api_session.invoke_api.assert_called_once_with(vim_util,
                                                        'get_object_property',
                                                        api_session.vim, task,
-                                                       'info')
+                                                       'info',
+                                                       skip_op_id=True)
 
     def test_wait_for_lease_ready(self):
         api_session = self._create_api_session(True)
@@ -470,7 +474,8 @@ class VMwareAPISessionTest(base.TestCase):
         api_session.invoke_api.assert_called_with(vim_util,
                                                   'get_object_property',
                                                   api_session.vim, lease,
-                                                  'state')
+                                                  'state',
+                                                  skip_op_id=True)
         self.assertEqual(num_states, api_session.invoke_api.call_count)
 
     def test_wait_for_lease_ready_with_error_state(self):
@@ -487,7 +492,8 @@ class VMwareAPISessionTest(base.TestCase):
                               api_session.wait_for_lease_ready,
                               lease)
         exp_calls = [mock.call(vim_util, 'get_object_property',
-                               api_session.vim, lease, 'state')] * 2
+                               api_session.vim, lease, 'state',
+                               skip_op_id=True)] * 2
         exp_calls.append(mock.call(vim_util, 'get_object_property',
                                    api_session.vim, lease, 'error'))
         self.assertEqual(exp_calls, api_session.invoke_api.call_args_list)
@@ -506,7 +512,8 @@ class VMwareAPISessionTest(base.TestCase):
         api_session.invoke_api.assert_called_once_with(vim_util,
                                                        'get_object_property',
                                                        api_session.vim,
-                                                       lease, 'state')
+                                                       lease, 'state',
+                                                       skip_op_id=True)
 
     def test_wait_for_lease_ready_with_invoke_api_exception(self):
         api_session = self._create_api_session(True)
@@ -518,7 +525,7 @@ class VMwareAPISessionTest(base.TestCase):
                           lease)
         api_session.invoke_api.assert_called_once_with(
             vim_util, 'get_object_property', api_session.vim, lease,
-            'state')
+            'state', skip_op_id=True)
 
     def _poll_task_well_known_exceptions(self, fault,
                                          expected_exception):
