@@ -374,6 +374,30 @@ class ServiceTest(base.TestCase):
         svc_obj.client.options.transport.cookiejar = [cookie]
         self.assertIsNone(svc_obj.get_http_cookie())
 
+    def test_set_soap_headers(self):
+        def fake_set_options(*args, **kwargs):
+            headers = kwargs['soapheaders']
+            self.assertEqual(1, len(headers))
+            txt = headers[0].getText()
+            self.assertEqual('fira-12345', txt)
+
+        svc_obj = service.Service()
+        svc_obj.client.options.soapheaders = None
+        setattr(svc_obj.client, 'set_options', fake_set_options)
+        svc_obj._set_soap_headers('fira-12345')
+
+    def test_soap_headers_pbm(self):
+        def fake_set_options(*args, **kwargs):
+            headers = kwargs['soapheaders']
+            self.assertEqual(2, len(headers))
+            self.assertEqual('vc-session-cookie', headers[0].getText())
+            self.assertEqual('fira-12345', headers[1].getText())
+
+        svc_obj = service.Service()
+        svc_obj._vc_session_cookie = 'vc-session-cookie'
+        setattr(svc_obj.client, 'set_options', fake_set_options)
+        svc_obj._set_soap_headers('fira-12345')
+
 
 class MemoryCacheTest(base.TestCase):
     """Test class for MemoryCache."""
